==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storsimple/kotlin/inputs/ListDeviceFailoverSetsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storsimple.kotlin.inputs

import com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name
 * @property managerName The manager name
 * @property resourceGroupName The resource group name
 */
public data class ListDeviceFailoverSetsPlainArgs(
    public val deviceName: String,
    public val managerName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs =
        com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .managerName(managerName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDeviceFailoverSetsPlainArgs].
 */
@PulumiTagMarker
public class ListDeviceFailoverSetsPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var managerName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name
     */
    @JvmName("xnkcqvwrxdjcktyu")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The manager name
     */
    @JvmName("ovvqvtlgnsfgfvpo")
    public suspend fun managerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managerName = mapped
    }

    /**
     * @param value The resource group name
     */
    @JvmName("ueuiujehyeerfjoj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListDeviceFailoverSetsPlainArgs = ListDeviceFailoverSetsPlainArgs(
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        managerName = managerName ?: throw PulumiNullFieldException("managerName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storsimple/kotlin/inputs/ListDeviceFailoverSetsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storsimple.kotlin.inputs

import com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name
 * @property managerName The manager name
 * @property resourceGroupName The resource group name
 */
public data class ListDeviceFailoverSetsPlainArgs(
    public val deviceName: String,
    public val managerName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs =
        com.pulumi.azurenative.storsimple.inputs.ListDeviceFailoverSetsPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .managerName(managerName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDeviceFailoverSetsPlainArgs].
 */
@PulumiTagMarker
public class ListDeviceFailoverSetsPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var managerName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name
     */
    @JvmName("colptchechcyuynp")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The manager name
     */
    @JvmName("nfhbecpovbkyytfp")
    public suspend fun managerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.managerName = mapped
    }

    /**
     * @param value The resource group name
     */
    @JvmName("mfsyhprllvfeigtt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListDeviceFailoverSetsPlainArgs = ListDeviceFailoverSetsPlainArgs(
        deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
        managerName = managerName ?: throw PulumiNullFieldException("managerName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
